//SORTCEJ1 JOB SIMOTIME,CLASS=1,MSGCLASS=0,NOTIFY=CSIP1
//* *******************************************************************
//*        This program is provided by SimoTime Technologies          *
//*           (C) Copyright 1987-2016 All Rights Reserved             *
//*             Web Site URL:   http://www.simotime.com               *
//*                   e-mail:   helpdesk@simotime.com                 *
//* *******************************************************************
//*
//* Text   - Create a Sequential Data Set using IEBGENER and Sort.
//* Author - SimoTime Technologies
//* Date   - January 24, 1996
//*
//* Step 1, DELSEQS1 will delete any previously created file.
//* Step 2, CRTSEQS2 will create a new file.
//* Step 3, SRTSEQS3 will sort the file.
//* Step 4, EXTENDS4 will add a record to the input file.
//* Step 5, SRTSEQS5 will do a case insensitive sort of the file .
//*
//* CAUTION! Since the ALTSEQ is defined at the binary (or hexadecimal)
//*          level step 5 will only work for EBCDIC-encoded files.
//*
//* Refer to SORTCAJ1.JCL for a case insensitive sort for the ASCII
//* encoded environment.
//*
//* This job uses instream sorting specifications.
//*
//* This set of programs will run on a mainframe under MVS or on a
//* Personal Computer with Windows and Micro Focus Mainframe Express.
//*
//* 1. Demonstrate how to use IEFBR14 with DD statements to delete
//*    files that have been created by a previous execution of this
//*    job.
//* 2. Demonstrate how to use IEBGENER to create and populate a new
//*    record sequential file with eighty (80) byte fixed length
//*    records.
//* 3. Demonstrate how to use the SORT program to sort a file based
//*    on the value in position five (5) of each record.
//* 4. Demonstrate how to do a case insensitive sort. A normal sort
//*    sequence will sort all the uppercase together and then all the
//*    lower case together in a group, for example ABCDEabcde.
//*    Sometimes it is desirable to sort the upper and lower case
//*    together, for example AaBbCcDdEe. This is referred to as a
//*    case insensitive sort.
//*
//* *******************************************************************
//* Step   1 of 5, Delete any previously created file...
//*
//DELSEQS1 EXEC PGM=IEFBR14
//SEQBFORE DD  DSN=SIMOTIME.DATA.SEQBE4D1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//SEQAFTD1 DD  DSN=SIMOTIME.DATA.SEQAFTD1,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//SEQAFTD2 DD  DSN=SIMOTIME.DATA.SEQAFTD2,DISP=(MOD,DELETE,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//*
//* *******************************************************************
//* Step   2 of 5, Create and populate a new QSAM file...
//*
//CRTSEQS2 EXEC PGM=IEBGENER
//SYSPRINT DD  SYSOUT=*
//SYSIN    DD  DUMMY
//SYSUT1   DD  *
000   ...1....:....2....:....3....:....4....:....5....:....6....:....7.
001 A C1 1100 0001 41 0100 0001
002 B C2 1100 0010 42 0100 0010
003 0 F0 1111 0000 30 0011 0000
004 C C3 1100 0011 43 0100 0011
005 a 81 1000 0001 61 0110 0001
006 b 82 1000 0010 62 0110 0010
007 1 F1 1111 0001 31 0011 0001
/*
//SYSUT2   DD  DSN=SIMOTIME.DATA.SEQBE4D1,
//             DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//*
//* *******************************************************************
//* Step   3 of 5, Sort the file...
//*
//SRTSEQS3 EXEC PGM=SORT,
//             REGION=1024K
//SYSIN    DD  *
* ..:....1....:....2....:....3....:....4....:....5....:....6....:....7.
         SORT  FIELDS=(5,1,CH,A,1,3,CH,A)
/*
//SORTIN   DD  DSN=SIMOTIME.DATA.SEQBE4D1,DISP=SHR
//SORTOUT  DD  DSN=SIMOTIME.DATA.SEQAFTD1,DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
//*
//* *******************************************************************
//* Step   4 of 5, Extend or add records to an existing QSAM file...
//*
//EXTENDS4 EXEC PGM=IEBGENER
//SYSPRINT DD  SYSOUT=*
//SYSIN    DD  DUMMY
//* :....1....:....2....:....3....:....4....:....5....:....6....:....7.
//SYSUT1   DD  *
999 9 F9 1111 1001 39 0011 1001
/*
//SYSUT2   DD  DSN=SIMOTIME.DATA.SEQBE4D1,
//             DISP=(MOD,KEEP,KEEP),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//*
//* *******************************************************************
//* Step   5 of 5, Do a Case Insensitive Sort of the file...
//*
//* CAUTION! Since the ALTSEQ is defined at the binary (or hexadecimal)
//*          level step 5 will only work for EBCDIC-encoded files.
//*
//SRTSEQS5 EXEC PGM=SORT,
//             REGION=1024K
//SYSIN    DD  *
* ..:....1....:....2....:....3....:....4....:....5....:....6....:....7.
  SORT FIELDS=(5,1,AQ,A)
  ALTSEQ CODE=(81C1,82C2,83C3,84C4,85C5,86C6,87C7,88C8,89C9,
               91D1,92D2,93D3,94D4,95D5,96D6,97D7,98D8,99D9,
               A2E2,A3E3,A4E4,A5E5,A6E6,A7E7,A8E8,A9E9)
/*
//SORTIN   DD  DSN=SIMOTIME.DATA.SEQBE4D1,DISP=SHR
//SORTOUT  DD  DSN=SIMOTIME.DATA.SEQAFTD2,DISP=(NEW,CATLG,DELETE),
//             STORCLAS=MFI,
//             SPACE=(TRK,5),
//             DCB=(RECFM=FB,LRECL=80,BLKSIZE=800,DSORG=PS)
//SYSOUT   DD  SYSOUT=*
