@echo OFF
rem  * *******************************************************************
rem  *               SORTE5E1.CMD - a Windows Command File               *
rem  *         This program is provided by SimoTime Technologies         *
rem  *           (C) Copyright 1987-2016 All Rights Reserved             *
rem  *             Web Site URL:   http://www.simotime.com               *
rem  *                   e-mail:   helpdesk@simotime.com                 *
rem  * *******************************************************************
rem  * Step 1, Set environment and delete any previously created files.
rem  * Step 2, Create an ASCII/Text (or Line Sequential) file using the
rem  *         Windows echo command and piping the output to SORTIN.
rem  * Step 3, Sort the SORTIN file and create SORTOUT. The sorting
rem  *         specifications are included as a command line parameter.
rem  *         The SORTIN file is an ASCII/Text file.
rem  *         The SORTOUT file is an EBCDIC-encoded, record sequential
rem  *         file with eighty (80) byte, fixed length records.
rem  ******************************************************************
rem  *   Step 1 of 4, Set Environment, Delete previously created files
:STEP01
     call SimoNOTE "* Set environment, delete previously created files"
rem  * The ezSetEnv is a Windows Command file that sets environment
rem  * variables that are common to a variety of sample applications
rem  * provided in the SimoTime collection.
     call ..\Env1BASE
     call SimoNOTE "* SORTE5E1.CMD is STARTING..."
rem  * Set environment variables that are unique to this job...
     set SORTIN=%BaseLib1%\DATA\Wrk1\SRTBFORE.TXT
     set SORTOUT=%BaseLib1%\DATA\Wrk1\SRTERSEQ.DAT
rem  * Delete previously created files...
     if exist %SORTIN%  erase %SORTIN%
     if exist %SORTOUT% erase %SORTOUT%
rem  *
rem  ******************************************************************
rem  *  Step 2 of 4, Create a test file to be sorted
:STEP02
     call SimoNOTE "* Create a Test File for SORTIN "
rem  *    ....:....1....:....2....:....3....:....4....:....5....:....6
     echo 001 A C1 1100 0001 41 0100 0001>  %SORTIN%
     echo 002 C C3 1100 0011 43 0100 0011>> %SORTIN%
     echo 003 0 F0 1111 0000 30 0011 0000>> %SORTIN%
     echo 004 c 83 1000 0011 63 0110 0031>> %SORTIN%
     echo 005 B C2 1100 0010 42 0100 0010>> %SORTIN%
rem  *
rem  ******************************************************************
rem  *   Step 3 of 4, Convert to EBCDIC and Sort
:STEP03
     call SimoNOTE "* Convert to EBCDIC and Sort"
     MFSORT CHAR-EBCDIC SORT FIELDS=(5,1,CH,A,1,3,CH,A) use %SORTIN% ORG LS give %SORTOUT% RECORD F,80 ORG SQ
     if "%errorlevel%" == "1" set JobStatus=0016
     echo Job Status after the SORT is = %JobStatus%
     if not "%JobStatus%" == "0000" goto :EOJNOK
rem  *
rem  ******************************************************************
rem  * Step 4 of 4, Sort using a User-Defined ALTSEQ Table
:STEP04
     set SORTOUT=%BaseLib1%\DATA\Wrk1\SRTELSEQ.txt
     set ALTSEQT1=%BaseLib1%\PARMLIB\SRTE4AT1.ctl
     call SimoNOTE "* Sort using a User-Defined ALTSEQ Table "
     MFSORT take %ALTSEQT1% use %SORTIN% ORG LS give %SORTOUT% ORG LS
     if "%errorlevel%" == "1" set JobStatus=0016
     echo Job Status after the SORT is = %JobStatus%
     if not "%JobStatus%" == "0000" goto :EOJNOK
rem  *
rem  ******************************************************************
rem  * Normal EOJ, Display the sorted test file
:EOJAOK
     call SimoNOTE "* SORTE5E1.CMD is FINISHED..."
     echo SORTOUT=%SORTOUT%
     goto :EOJ
rem  *
rem  ******************************************************************
rem  * ABENDING, display a message and pause
:EOJNOK
     call SimoNOTE "* SORTE5E1.CMD is ABENDING..."
rem  *
rem  ******************************************************************
rem  * ABENDING, display a message and pause
:EOJ
     pause
     exit /B %JobStatus%
